
#include <string.h>

/* 
 * For session recording management.
 */
#define SESSION_REC_OFF		0
#define SESSION_REC_ON		1
#define SESSION_REC_PLAY	2
#define SESSION_SET_EVENT	1
#define SESSION_START		0
#define SESSION_END			1

/*
 * Command set.
 */
#define MASTER_EVENT		2
#define TRACK_EVENT			3
#define BUS_EVENT			4
#define SBUS_EVENT			5
#define EFFECT_EVENT		6
#define MIDI_EVENT			7 /* Not implemented */
#define FB_EVENT			8
#define TAPE_EVENT			9 /* Not implemented, but will be soon */

/*
 * These are actually SLab internal definitions. They should not really be
 * here.
 */
#define NEW_SESSION_EVENT	1
#define DISABLED_EVENT		2
#define SESS_REMOVE_EVENT	1
#define SESS_ENABLE_EVENT	2
#define SESS_DISABLE_EVENT	3

/*
 * And finally, this is the set of operations supported by SLab. Note that the
 * control API actually links into the session recording capabilities, since 
 * this is a single point of convergence for all GUI mix events.
 *
 * To link this to MIDI messages, parameters listed here should be assigned to
 * some continuous controller in the MIDI domain. Since there are not so many
 * continuous controllers, then it is possible the MIDI will have to use 
 * SYSEX messaging.
 *
 * NOTES:
 * Most of these are continuous controllers. Many of the buttons are not yet
 * automated. Also, there is no interface to change the song file name, or the
 * audio devices. This can all be built in at a later date.
 */
#define VOLSCALER			0
#define GAIN				1
#define RECTREB				2
#define RECMID				3
#define RECBASS				4
#define SEND1VOL			5
#define SEND2VOL			6
#define PAN					7
#define SPECIAL				8
#define BASSLIMIT			9
#define BASSGAIN			10
#define BASSSWEEP			11
#define BASSQ				12
#define TREBLIMIT			13
#define TREBGAIN			14
#define TREBSWEEP			15
#define TREBQ				16
#define FILTERACT			17
#define FILTERALGO			18
#define BUSSELECT			19
#define SEND1BUS			20
#define SEND2BUS			21
#define SEND1ACT			22
#define SEND2ACT			23
#define DOBOOST				24
#define MICROCD				25
#define MICROPCM			26
#define MICROMIC			27
#define MICROSYNTH			28
#define MICROLINE			29
#define MICROLINE1			30
#define MICROLINE2			31
#define MICROLINE3			32
#define MASTERVOL			33
#define MASTERRIGHT			34
#define MASTERLEFT			35
#define MASTERTREBLERIGHT	36
#define MASTERTREBLELEFT	37
#define MASTERMIDDLERIGHT	38
#define MASTERMIDDLELEFT	39
#define MASTERBASSRIGHT		40
#define MASTERBASSLEFT		41
#define MASTERRETURN1RIGHT	42
#define MASTERRETURN2RIGHT	43
#define MASTERRETURN1LEFT	44
#define MASTERRETURN2LEFT	45
#define WOWFLUTTER			46
#define CROSSTALK			47
#define SCRATCHLEVEL		48
#define SCRATCHDENSITY		49
#define SCRATCHALGO			50
#define RETURNVOL			51
#define RETURNLEFT			52
#define RETURNRIGHT			53
#define BUSSELECT2			54
#define BUSVOL				55
#define BUSLEFT				56
#define BUSRIGHT			57
#define EFFECTPARAM			58
#define DYNGAIN				59
#define DYNLIMIT			60
#define DYNRAMP				61
#define DYNACT				62
#define DYNALGO				63
#define SEND0_ACT			64
#define SEND1_ACT			65
#define SEND2_ACT			66
#define SEND3_ACT			67
#define SEND0_BUS			68
#define SEND1_BUS			69
#define SEND2_BUS			70
#define SEND3_BUS			71
#define SEND0_VOL			72
#define SEND1_VOL			73
#define SEND2_VOL			74
#define SEND3_VOL			75
#define PARALIM				76
#define PARAGAIN			77
#define PARAQ				78
#define DYNRAMPDOWN			79
#define DYNRELEASE			80
/*
 * The following are reserved, but not implemented
 */
#define MIDI_VOL			81
#define MIDI_TRANSP			82
#define MIDI_MASTER_VOL		83
#define MIDI_BUS_VOL		84
#define MIDI_DEV_VOL		85
#define MIDI_PAN			86
#define MIDI_MASTER_PAN		87
#define MIDI_BUS_PAN		88
#define MIDI_DEV_PAN		89
#define MIDI_USER0			90
#define MIDI_MASTER0		91
#define MIDI_BUS0			92
#define MIDI_DEV0			93
#define MIDI_USER1			94
#define MIDI_MASTER1		95
#define MIDI_BUS1			96
#define MIDI_DEV1			97
#define MIDI_USER2			98
#define MIDI_MASTER2		99
#define MIDI_BUS2			100
#define MIDI_DEV2			101
#define MIDI_USER3			102
#define MIDI_MASTER3		103
#define MIDI_BUS3			104
#define MIDI_DEV3			105
#define TRACK_SELECT		106
#define MIDI_CLOCK			107 /* Added for 3.20 */

#define LIST_END			108

typedef struct limits {
	int min;
	int max;
} limits;

/*
 * Param limits will be used to scale the 15 bit continuous controller values
 * to the internal limits of each parameter. This is initialised only at the
 * server side.
 */
limits paramLimits[LIST_END];

